@@ -42,8 +42,7 @@ class App:
             server_name=socket.gethostname()
         )
         
-        # self._create_defaults()
-
+        
     def wsgi_app(self, environ, start_response):
         request = Request(environ)
 
@@ -85,7 +84,6 @@ class App:
 
     def default_response(self, response):
         response.status_code = 404
-        # response.body = self.custom_template("selfpages", "error-404.html")
         self.exception_handler.handle_404(response)
 
     def find_handler(self, request_path):
@@ -130,11 +128,6 @@ class App:
         self.templates_env = Environment(
             loader=FileSystemLoader(os.path.abspath(templates_dir)))
         self.templates_dir = templates_dir
-    
-    def create_defaults(self):
-        os.mkdir("apppages")
-        with open(f'{pathlib.Path("apppages")}/error-500.html', "w") as f:
-            f.write("...")
             
 
     def run(self):
